@@ -1,7 +1,6 @@
 import json
 from pathlib import Path
 
-import numpy as np
 import pytest
 from appdirs import user_config_dir
 
@@ -28,7 +27,7 @@ def test_constants():
 
 @pytest.mark.parametrize("value", [123.234, 23.4576585, 234])
 def test__round(value):
-    assert int(100 * value) / 100 == lpl._round(value)
+    assert int(10 * value) / 10 == lpl._round(value)
 
 
 class TestSetPageSize:
@@ -126,6 +125,22 @@ class TestSetSize:
         assert res_width <= width * max(fraction, 1)
         assert res_height <= height * max(fraction, 1)
 
+    @pytest.mark.parametrize("nrows", [1, 2])
+    @pytest.mark.parametrize("ncols", [1, 2])
+    @pytest.mark.parametrize("fraction", [0.5, 1.0, 2.0])
+    @pytest.mark.parametrize("ratio", [GOLDEN_RATIO, 1, 2])
+    def test_nrows_ncols_with_ratio(self, monkeypatch, nrows, ncols, fraction, ratio):
+        monkeypatch.setattr(lpl, "get_page_size", lambda: (WIDTH, HEIGHT))
+
+        width = ncols * lpl._round(lpl.convert_pt_to_in(WIDTH))
+        height = nrows * lpl._round(lpl.convert_pt_to_in(WIDTH / ratio))
+
+        res_width, res_height = lpl._set_size(
+            nrows, ncols, fraction=fraction, ratio=ratio
+        )
+        assert res_width <= width * max(fraction, 1)
+        assert res_height <= height * max(fraction, 1)
+
     def test_negative_fraction(self):
         with pytest.raises(ValueError):
             lpl._set_size(1, 1, fraction=-1)
